.. _contributing:

=========================
Contributing to Ironic UI
=========================

If you're interested in contributing to the Ironic UI project,
the following will help get you started.

Contributor License Agreement
-----------------------------

.. index::
   single: license; agreement

In order to contribute to the Ironic project, you need to have
signed OpenStack's contributor's agreement.

.. seealso::

   * http://docs.openstack.org/infra/manual/developers.html
   * http://wiki.openstack.org/CLA

LaunchPad Project
-----------------

Most of the tools used for OpenStack depend on a launchpad.net ID for
authentication.

.. seealso::

   * https://launchpad.net
   * https://launchpad.net/ironic

Project Hosting Details
-------------------------

Bug tracker
    http://launchpad.net/ironic-ui

Mailing list (prefix subjects with ``[ironic-ui]`` for faster responses)
    http://lists.openstack.org/cgi-bin/mailman/listinfo/openstack-dev

Code Hosting
    https://github.com/openstack/ironic-ui

Code Review
    https://review.openstack.org/#/q/status:open+project:openstack/ironic-ui,n,z


